#include "msp.h"
#include "gpio.h"
#include "fifo_function_queue.h"

//Callback function for queue
void (*button_pressed_callback)();

void initializeGPIOModule(void)
{
    //Configures Port1 pins according to SLAU597F (MSP432 Launchpad User Guide)
    P1OUT = 0;
    P1DIR = 0xE9;
    P1SEL1 = 0;
    P1SEL0 = 0xE6;

    P2OUT = 0;
    P2DIR = 0xFF;
    P2SEL1 = 0;
    P2SEL0 = 0xF0;

    //Configure Interrupt for P1.4
    P1IFG = 0;
    P1IES = 0;  //Low to high transition for the ISR
    P1IE |= BIT4;   //Enable interrupt

    //Enable Pull-Up for P1.4
    P1OUT |= BIT4;   //Enable interrupt
    P1REN |= BIT4;   //Enable interrupt

    NVIC_SetPriority(PORT1_IRQn,3);
    NVIC_EnableIRQ(PORT1_IRQn); // Enable PORT1 Interrupt

    //TODO Configure other ports
}

void turnOnLED(int identifier)
{
    switch (identifier)
    {
        case LED_ONE:
            P1OUT |= BIT0;
            break;
        case LED_RED:
            P2OUT |= BIT0;
            break;
        case LED_GREEN:
            P2OUT |= BIT1;
            break;
        case LED_BLUE:
            P2OUT |= BIT2;
            break;
    }
}

void turnOffLED(int identifier)
{
    switch (identifier)
    {
        case LED_ONE:
            P1OUT &= ~BIT0;
            break;
        case LED_RED:
            P2OUT &= ~BIT0;
            break;
        case LED_GREEN:
            P2OUT &= ~BIT1;
            break;
        case LED_BLUE:
            P2OUT &= ~BIT2;
            break;
    }
}

void setBluetoothButtonISRCallbackFunction(void *callback_function)
{
    button_pressed_callback = callback_function;
}

void PORT1_IRQHandler(void)
{
    if(P1IFG & BIT4){

        addToFunctionQueue(button_pressed_callback);
        P1IFG &= ~BIT4;
    }
}





